column_base_height

Function column_base_height 

pub(crate) fn column_base_height<N: DimensionNoises>(
    cache: &mut N::ColumnCache,
    noises: &N,
    aquifer: &mut Aquifer<N>,
    x: i32,
    z: i32,
    ocean_floor: bool,
) -> i32
getBaseHeight(WORLD_SURFACE_WG)-compatible height scan. Uses preliminary_surface_level + 16 as an upper bound to avoid scanning empty upper atmosphere, and the cell-based iterator so 8-corner density evaluations are shared across Y values in each cell.

Exposed for GenerationContext.