interpolated_density

Function interpolated_density 

fn interpolated_density<N: DimensionNoises>(
    cache: &mut N::ColumnCache,
    noises: &N,
    x: i32,
    y: i32,
    z: i32,
    cell_w: i32,
    cell_h: i32,
) -> f64
Evaluate terrain density at a single block position using cell-based interpolation matching vanilla’s NoiseChunk: inner functions at 8 cell corners, trilinear interpolation per channel, then outer operations.